@@ -2,7 +2,7 @@ from base import RESTModel
 
 
 class NodeCluster(RESTModel):
-    """Represents a Tutum nodecluster object"""
+    """Represents a Tutum NodeCluster object"""
 
     endpoint = "/nodecluster"
 
